Enum Backend
pub enum Backend {
Best,
Hardware(Api),
Software,
Custom(String),
}Expand description
A graphical backend.
You can override the default strategy by setting the ICED_BACKEND environment variable.
If you are using the default renderer, the available options are:
wgpufor the hardware accelerated backend.tiny-skiafor the software-based backend.
Variants
Best
Auto-detect and choose the best available Backend.
Hardware(Api)
Hardware accelerated graphics backend with the given Api.
Software
Sofware graphics backend; quite slower than hardware-based backends, but more compatible.
Custom(String)
A custom rendering backend with the given name.
Implementations
impl Backend
impl Backend
pub fn hardware(&self) -> Option<Api>
pub fn hardware(&self) -> Option<Api>
Returns true if the Backend is Backend::Hardware.
pub fn is_software(&self) -> bool
pub fn is_software(&self) -> bool
Returns true if the Backend is Backend::Software.
pub fn matches(&self, target: &str) -> bool
pub fn matches(&self, target: &str) -> bool
Returns true if the Backend is Backend::Best or matches the given name.